# Lattice module

## General lattice functions

::: pqlattice.lattice.volume

::: pqlattice.lattice.rank

::: pqlattice.lattice.hadamard_ratio

::: pqlattice.lattice.discriminant

::: pqlattice.lattice.gaussian_heuristic

::: pqlattice.lattice.is_lll_reduced

::: pqlattice.lattice.is_size_reduced

---

## Lattice reduction algorithms
::: pqlattice.lattice.gso

::: pqlattice.lattice.lll

::: pqlattice.lattice.bkz

::: pqlattice.lattice.hkz

::: pqlattice.lattice.glr_2dim

---

## SVP and CVP
::: pqlattice.lattice.shortest_vector

::: pqlattice.lattice.babai_closest_vector

::: pqlattice.lattice.babai_nearest_plane

---

## Lattice embeddings
::: pqlattice.lattice.embeddings.sis_basis

::: pqlattice.lattice.embeddings.lwe_basis

::: pqlattice.lattice.embeddings.kannan

::: pqlattice.lattice.embeddings.bai_galbraith

::: pqlattice.lattice.embeddings.subset_sum

::: pqlattice.lattice.embeddings.ntru
